@@ -139,12 +139,6 @@ class ModelRepoSourceKind(str, enum.Enum):
     AZURE = "azure"
 
 
-class ModelWeightsFormat(str, enum.Enum):
-    """Predefined supported model weights formats for deploying model from checkpoints via `truss train deploy_checkpoints`."""
-
-    LORA = "LoRA"
-
-
 class ModelRepo(custom_types.ConfigModel):
     repo_id: Annotated[str, pydantic.StringConstraints(min_length=1)]
     revision: Optional[Annotated[str, pydantic.StringConstraints(min_length=1)]] = None
@@ -547,21 +541,19 @@ class BaseImage(custom_types.ConfigModel):
 
 
 class DockerServer(custom_types.ConfigModel):
-    start_command: str
+    start_command: Optional[str] = None
     server_port: int
     predict_endpoint: str
     readiness_endpoint: str
     liveness_endpoint: str
+    run_as_user_id: Optional[int] = None
+    no_build: Optional[bool] = None
 
-
-# TODO: aghilann: remove this once we have LoRA checkpoints
-class Checkpoint(custom_types.ConfigModel):
-    # NB(rcano): The id here is a formatted string of the form <training_job_id>/<checkpoint_id>
-    # We do this because the vLLM command requires knowledge of where the checkpoint
-    # is downloaded. By using a formatted string instead of an additional "training_job_id"
-    # field, we provide a more transparent truss config.
-    id: str
-    name: str
+    @pydantic.model_validator(mode="after")
+    def _validate_start_command(self) -> "DockerServer":
+        if not self.no_build and self.start_command is None:
+            raise ValueError("start_command is required when no_build is not true")
+        return self
 
 
 class TrainingArtifactReference(custom_types.ConfigModel):
@@ -580,10 +572,6 @@ class CheckpointList(custom_types.ConfigModel):
         description="The folder to download the checkpoints to.",
         examples=["/tmp/training_checkpoints"],
     )
-    # TODO: Remove this field once deploy_checkpoints uses artifact_references instead.
-    checkpoints: list[Checkpoint] = pydantic.Field(
-        default_factory=list, deprecated="Prefer artifact_references instead."
-    )
     artifact_references: list[TrainingArtifactReference] = pydantic.Field(
         default_factory=list
     )
@@ -747,6 +735,12 @@ class TrussConfig(custom_types.ConfigModel):
         exclude_unset = bool(info.context and "verbose" in info.context)
         return trt_llm.model_dump(exclude_unset=exclude_unset)
 
+    # NB(nikhil): clear_runtime_fields will remove all runtime specific fields from the config so
+    # we can more optimally detect whether a new image build is needed.
+    def clear_runtime_fields(self) -> None:
+        self.training_checkpoints = None
+        self.environment_variables = {}
+
 
 def _map_to_supported_python_version(python_version: str) -> str:
     """Map python version to truss supported python version.
